package
Version:
v0.0.0-...-299b620
Opens a new window with list of versions in this module.
Published: Dec 8, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Data struct {
EventName string `json:"method"`
Payload interface{} `json:"data"`
}
Data is an example model
type TestData struct {
RoomId string `json:"roomId"`
RoomTotaltextNums int `json:"roomTotaltextNums"`
AppData interface{} `json:"appData"`
PeerName string `json:"peerName"`
TextNums int `json:"textNums"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.